@@ -215,17 +215,63 @@ badge_sci_citation <- function(url, color) {
 ##' @param color color of the badge. If missing, the color is determined by the stage.
 ##' @return badge in markdown syntax
 ##' @export
-##' @author Gregor de Cillia
+##' @author Gregor de Cillia, Waldir Leoncio
 badge_lifecycle <- function(stage = "experimental", color = NULL) {
   url <- paste0("https://lifecycle.r-lib.org/articles/stages.html#", stage)
-  if (is.null(color))
-    color <- switch(stage, experimental = "orange", maturing = "blue", stable = "brightgreen",
-                    retired = "orange", archived = "red", dormant = "blue", questioning = "blue",
-                    superseded = "blue",
-                    stop("invalid stage: ", stage))
+  if (is.null(color)) {
+    color <- switch(
+      stage,
+      stable       = "brightgreen",
+      deprecated   = "orange",
+      superseded   = "blue",
+      experimental = "orange",
+      stop("invalid stage: ", stage)
+    )
+  }
   badge_custom("lifecycle", stage, color, url)
 }
 
+##' repostatus.org badge
+##'
+##'
+##' @title badge_repostatus
+##' @param status project status (Concept, WIP, Suspended, Abandoned, Active,
+##' Inactive, Unsupported, Moved). See
+##' \href{https://www.repostatus.org/lifecycle}{https://www.repostatus.org/lifecycle}
+##' for more details.
+##' @param alt Alternative text
+##' @return badge in markdown syntax
+##' @export
+##' @author Waldir Leoncio
+badge_repostatus <- function(status, alt = NULL) {
+  status <- tolower(status)
+  svg <- paste0("https://www.repostatus.org/badges/latest/", status, ".svg")
+  url <- paste0("https://www.repostatus.org/#", status)
+  if (is.null(alt)) {
+    alt <- switch(
+      status,
+      concept     = "Concept - Minimal or no implementation has been done yet, or the repository is only intended to be a limited example, demo, or proof-of-concept.",
+      wip         = "WIP - Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.",
+      suspended   = "Suspended - Initial development has started, but there has not yet been a stable, usable release; work has been stopped for the time being but the author(s) intend on resuming work.",
+      abandoned   = "Abandoned - Initial development has started, but there has not yet been a stable, usable release; the project has been abandoned and the author(s) do not intend on continuing development.",
+      active      = "Active - The project has reached a stable, usable state and is being actively developed.",
+      inactive    = "Inactive - The project has reached a stable, usable state but is no longer being actively developed; support/maintenance will be provided as time allows.",
+      unsupported = "Unsupported - The project has reached a stable, usable state but the author(s) have ceased all work on it. A new maintainer may be desired.",
+      moved       = "Moved to http://example.com - The project has been moved to a new location, and the version at that location should be considered authoritative.",
+      stop("invalid status: ", status)
+    )
+    alt <- paste("Project Status:", alt)
+  }
+  badge_out <- paste0("[![", alt, "](", svg, ")](", url, ")")
+  if (status == "moved") {
+    warning("Please remember to replace 'http://example.com' with the new URL")
+    paste(badge_out, "to [http://example.com](http://example.com)")
+  } else {
+    paste(badge_out)
+  }
+}
+
+
 ##' last commit badge
 ##'
 ##'
@@ -298,9 +344,10 @@ badge_code_size <- function(ref = NULL) {
 ##' @return badge in markdown syntax
 ##' @export
 ##' @author Gregor de Cillia
-badge_cran_release <- function(pkg = NULL, color) {
+badge_cran_release <- function(pkg = NULL, color = NULL) {
   pkg <- currentPackageName(pkg)
-  svg <- paste0("https://www.r-pkg.org/badges/version/", pkg, "?color=", color)
+  svg <- paste0("https://www.r-pkg.org/badges/version/", pkg)
+  if (!is.null(color)) {svg <- paste0(svg, "?color=", color)}
   url <- paste0("https://cran.r-project.org/package=", pkg)
   placeholder <- "CRAN link"
   paste0("[![](", svg, ")](", url, ")")
@@ -346,12 +393,12 @@ badge_codecov <- function(ref = NULL, token = NULL, branch = NULL) {
   ref    <- currentGitHubRef(ref)
   branch <- defaultBranch(branch)
   svg    <- paste0(
-    "https://codecov.io/gh/", ref, "/branch/", branch, "/graph/badge.svg"
+    "https://app.codecov.io/gh/", ref, "/branch/", branch, "/graph/badge.svg"
   )
   if (!is.null(token)) {
     svg <- paste0(svg, "?token=", token)
   }
-  url <- paste0("https://codecov.io/gh/", ref)
+  url <- paste0("https://app.codecov.io/gh/", ref)
   paste0("[![](", svg, ")](", url, ")")
 }
 
@@ -367,10 +414,11 @@ badge_codecov <- function(ref = NULL, token = NULL, branch = NULL) {
 ##' @export
 ##' @author Gregor de Cillia
 badge_cran_download <- function(pkg = NULL, type = c("last-month", "last-week", "grand-total"),
-                                color = "green") {
+                                color = NULL) {
   pkg <- currentPackageName(pkg)
 	type <- match.arg(type)
-  svg <- paste0("http://cranlogs.r-pkg.org/badges/", type, "/", pkg, "?color=", color)
+  svg <- paste0("http://cranlogs.r-pkg.org/badges/", type, "/", pkg)
+  if (!is.null(color)) {svg <- paste0(svg, "?color=", color)}
   url <- paste0("https://cran.r-project.org/package=", pkg)
   placeholder <- "CRAN link"
   paste0("[![](", svg, ")](", url, ")")
@@ -466,4 +514,3 @@ badge_codefactor <- function(ref = NULL) {
   svg <- paste0(url, "/badge")
   paste0("[![CodeFactor](", svg, ")](", url, ")")
 }
-
